Module path_analysis

Module path_analysis 

Structs

VersionManagerInfo

Functions

detect_version_manager
Detect whether a path is under a version manager’s install directory.
files_have_same_content
Compare two files for byte-identical content. Returns true only if both files exist, have the same size, and identical content.
is_build_output
Detect whether a path is inside a build output directory.
is_ephemeral
Detect whether the parent directory of a path is a temporary/cache location.
is_executable
Check if a path is an executable file (Unix: has execute permission)
is_shim_by_name
Heuristic: if the symlink target name does not start with the candidate name, it is likely a shim dispatcher (e.g. git -> jj-worktree). Version suffixes like python3 -> python3.12 are not shims.
is_shim_path
Detect whether a path is inside a shim directory.