pub fn detect_version_manager(path: &Path) -> Option<VersionManagerInfo>Expand description
Detect whether a path is under a version manager’s install directory.
pub fn detect_version_manager(path: &Path) -> Option<VersionManagerInfo>Detect whether a path is under a version manager’s install directory.