Enum PathTag Copy item path Source #[non_exhaustive]
pub enum PathTag {
Show 13 variants Input,
InPathEnv(usize ),
SymlinkTo(PathBuf ),
Shim,
SameCanonical,
SameContent,
Relative,
NonNormalized,
DifferentBinary,
ManagedBy(String ),
BuildOutput,
Ephemeral,
NotExecutable,
}Expand description Observed properties of a candidate path.
Tags describe how a candidate was found and what role it plays. Multiple
tags can be attached to a single candidate. See Candidate::tags .
This enum is marked as non-exhaustive Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
The path that was passed as input
Found in PATH environment variable (holds discovery order: 0 = first PATH match)
Is a symlink, pointing to the given target
In a shim directory or symlink target name doesn’t match candidate name
Canonical path matches the input binary (same file)
File content matches the input binary byte-for-byte (copied identical binary)
Relative path (doesn’t start with /)
Non-normalized path (contains .. or . components)
Same name but different binary (canonical and content both differ)
Under a version manager (holds manager name)
Inside a build output directory
Inside a temporary/cache directory
Not directly executable (no execute permission, or ambiguous bare relative path)
Performs copy-assignment from
source.
Read more Formats the value using the given formatter.
Read more Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
Immutably borrows from an owned value.
Read more Mutably borrows from an owned value.
Read more 🔬 This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From <T> for U chooses to do.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more Uses borrowed data to replace owned data, usually by cloning.
Read more The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.